@@ -1,10 +1,10 @@
 #!/bin/bash
 # Build config for build.sh
 APP_NAME=ubufox
-CHROME_PROVIDERS="content locale skin"
+CHROME_PROVIDERS="content locale"
 CLEAN_UP=1
 ROOT_FILES=
-ROOT_DIRS="defaults components plugins"
+ROOT_DIRS="scripts defaults components modules"
 BEFORE_BUILD=
 BEFORE_PACK="sed -ri -e s/@DIST_RELEASE@/`lsb_release -r -s`/g -e s/@DIST_CODENAME@/`lsb_release -s -c`/g defaults/preferences/dist.js"
 AFTER_BUILD=
